==> deepin-polkit-agent-5.4.16-1.src.tar.gz: dde-polkit-agent-5.4.16/translations/dde-polkit-agent_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="96"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>རེག་ཡུན་ཐུང་བ། ར་སྤཽད་བྱེད་སྐབས་མཛུབ་མོ་ཕྱིར་མ་འཁྱེར།</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Verification failed, two chances left</source>
        <translation>ར་སྤྲོད་མི་ཐུབ་པས། ཁྱེད་ཀྱིས་ད་དུང་ཚོད་ལྟ་ཐེངས་2བྱེད་ཆོག</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="118"/>
        <location filename="../AuthDialog.cpp" line="303"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>གཏན་ཁེལ། </translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="213"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>ཁྱེད་ཀྱི་གསང་ཨང་ལམ་སེང་་བརྗེ་རོགས་གནང་། (གསང་ཨང་དུས་ཚོད་ཡོལ་འདུག)</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="278"/>
        <source>Wrong password, only one chance left</source>
        <translation>གསང་ཨང་ནོར་འདུག ད་དུང་གོ་སྐབས་1ཡོད།</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="281"/>
        <source>Wrong password, two chances left</source>
        <translation>གསང་ཨང་ནོར་འདུག ད་དུང་གོ་སྐབས་2ཡོད།</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="285"/>
        <source>Wrong password</source>
        <translation>གསང་ཨང་ནོར་འདུག</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="302"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
</context>
</TS>

==> deepin-polkit-agent-5.4.17-1.src.tar.gz: dde-polkit-agent-5.4.17/translations/dde-polkit-agent_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../AuthDialog.cpp" line="98"/>
        <source>Finger moved too fast, please do not lift until prompted</source>
        <translation>རེག་ཡུན་ཐུང་བ། ར་སྤཽད་བྱེད་སྐབས་མཛུབ་མོ་ཕྱིར་མ་འཁྱེར།</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="100"/>
        <source>Verification failed, two chances left</source>
        <translation>ར་སྤྲོད་མི་ཐུབ་པས། ཁྱེད་ཀྱིས་ད་དུང་ཚོད་ལྟ་ཐེངས་2བྱེད་ཆོག</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="120"/>
        <location filename="../AuthDialog.cpp" line="326"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>གཏན་ཁེལ། </translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="227"/>
        <source>You are required to change your password immediately (password expired)</source>
        <translation>ཁྱེད་ཀྱི་གསང་ཨང་ལམ་སེང་་བརྗེ་རོགས་གནང་། (གསང་ཨང་དུས་ཚོད་ཡོལ་འདུག)</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="299"/>
        <source>Locked, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wrong password, only one chance left</source>
        <translation type="vanished">གསང་ཨང་ནོར་འདུག ད་དུང་གོ་སྐབས་1ཡོད།</translation>
    </message>
    <message>
        <source>Wrong password, two chances left</source>
        <translation type="vanished">གསང་ཨང་ནོར་འདུག ད་དུང་གོ་སྐབས་2ཡོད།</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="301"/>
        <source>Wrong password</source>
        <translation>གསང་ཨང་ནོར་འདུག</translation>
    </message>
    <message>
        <location filename="../AuthDialog.cpp" line="325"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ།</translation>
    </message>
</context>
</TS>
